.. _schade:

SCHADE
######

“After 17 to 27 months of treatment, both haloperidol- and olanzapine-treated monkeys had an equivalent and highly significant 8% to 11% decrease in fresh brain weight and volume when compared with the sham group.”

Schade zijn de volgende ziektes veroorzaakt door antipsychotica:

| Akathisia
| Katatonie
| Tardieve Dyskinesie
| Extrapiramidale symptomen
| Karakterveranderingen
| Coma
| Parkinsonisme
| Dementie
| Diabetes
| Hersenweefselverlies - http://www.ncbi.nlm.nih.gov/pmc/articles/PMC3476840/

| Een patient kan door toediening van antipsychotica te maken krijgen met positieve en negatieve symptomen, symptomen van vergiftiging, onthoudingsverschijnselen en ernstige bijwerkingen, zie :ref:`symptomen`.
